@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (C) 2020 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2020-2021 Sébastien Helleu <flashcode@flashtux.org>
 #
 # This file is part of Tasksched.
 #
@@ -19,12 +19,17 @@
 
 """Task scheduler project."""
 
+from math import ceil
 from operator import attrgetter
 
-import datetime
-
 import holidays
 
+from tasksched.utils import (
+    is_business_day,
+    add_business_days,
+    string_to_date,
+)
+
 __all__ = (
     'Resource',
     'Task',
@@ -46,13 +51,19 @@ class Resource:  # pylint: disable=too-few-public-methods
 class Task:  # pylint: disable=too-few-public-methods
     """A task."""
 
-    def __init__(self, task_id, title, duration):
+    # pylint: disable=too-many-arguments
+    def __init__(self, task_id, title, duration, priority=0, max_resources=2):
         self.task_id = str(task_id)
         self.title = title
-        self.duration = duration
+        self.duration = ceil(duration)
+        self.priority = priority
+        self.max_resources = max_resources
 
     def __str__(self):
-        return f'Task {self.task_id} - {self.title}: {self.duration}d'
+        return (f'Task {self.task_id} - {self.title}: '
+                f'{self.duration}d, '
+                f'priority: {self.priority}, '
+                f'max resources: {self.max_resources}')
 
 
 class Project:
@@ -61,40 +72,57 @@ class Project:
     def __init__(self, config):
         project = config['project']
         self.name = project['name']
-        self.start_date = datetime.date.fromisoformat(
-            project.get('start', datetime.date.today().strftime('%Y-%m-%d'))
-        )
+        self.start_date = string_to_date(project.get('start'))
         self.holidays_iso = project.get('holidays')
         if self.holidays_iso:
-            self.dict_holidays = holidays.CountryHoliday(
+            self.hdays = holidays.CountryHoliday(
                 self.holidays_iso,
                 years=range(self.start_date.year,
                             self.start_date.year + 10),
             )
         else:
-            self.dict_holidays = {}
+            self.hdays = {}
+        # adjust the start date to the next business if needed
+        if not is_business_day(self.start_date, self.hdays):
+            self.start_date = add_business_days(self.start_date, 1, self.hdays)
         self.resources = [
-            Resource(res['id'], res['name'])
+            Resource(
+                res['id'],
+                res.get('name', res['id']),
+            )
             for res in config['resources']
         ]
         if not self.resources:
             raise ValueError('At least one resource is required')
         self.tasks = [
-            Task(task['id'], task['title'], task['duration'])
+            Task(
+                task['id'],
+                task.get('title', task['id']),
+                task['duration'],
+                task.get('priority', 0),
+                task.get('max_resources', 2),
+            )
             for task in config['tasks']
+            if task['duration'] > 0
         ]
         if not self.tasks:
             raise ValueError('At least one task is required')
 
-    def tasks_by_duration(self):
+    def sorted_tasks(self, key, reverse=False):
         """
-        Get list of tasks sorted duration from longest to shortest.
+        Get list of tasks sorted by priority (from higher to lower) and
+        duration (from longest to shortest).
 
+        :param tuple,list key: key(s) to sort tasks
+        :param bool reverse: reverse sort
         :rtype: list
-        :return: list of tasks with remaining days > 0, sorted by longest to
-            shortest
+        :return: sorted list of tasks
         """
-        return sorted(self.tasks, key=attrgetter('duration'), reverse=True)
+        return sorted(
+            self.tasks,
+            key=attrgetter(*key),
+            reverse=reverse,
+        )
 
     def __str__(self):
         str_res = '\n'.join([f'    {str(res)}' for res in self.resources])
