@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (C) 2020 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2020-2021 Sébastien Helleu <flashcode@flashtux.org>
 #
 # This file is part of Tasksched.
 #
@@ -20,6 +20,7 @@
 """Task scheduler work plan."""
 
 import copy
+import datetime
 
 from tasksched.project import Task
 from tasksched.utils import add_business_days
@@ -42,13 +43,13 @@ class WorkPlan:
             res.assigned_tasks = []
             res.duration = 0
             res.end_date = None
-            res.usage = 0
+            res.use = 0
         for task in self.project.tasks:
             task.remaining = task.duration
         self.remaining = sum(task.duration for task in self.project.tasks)
         self.duration = 0
         self.end_date = self.project.start_date
-        self.resources_usage = 0
+        self.resources_use = 0
         self.schedule()
 
     def split_tasks(self, tasks_to_split):
@@ -62,9 +63,11 @@ class WorkPlan:
         new_tasks = []
         for task in self.project.tasks:
             number = tasks_to_split.get(task.task_id, None)
-            if number is not None and number > 1:
+            if number is not None and 1 < number <= task.max_resources:
                 # split duration into multiple durations which are all almost
-                # the same, and sum == duration (and remove all null values)
+                # the same, and sum == duration (and remove all null values);
+                # for example if task.duration == 10 and number == 3,
+                # durations == [4, 3, 3]
                 durations = list(filter(None, [
                     task.duration // number + (1 if x < task.duration % number
                                                else 0)
@@ -72,10 +75,11 @@ class WorkPlan:
                 ]))
                 for i, duration in enumerate(durations):
                     title = f'{task.title} ({i+1}/{len(durations)})'
-                    new_tasks.append(Task(task.task_id, title, duration))
+                    new_tasks.append(Task(task.task_id, title, duration,
+                                          task.priority, task.max_resources))
             else:
-                new_tasks.append(
-                    Task(task.task_id, task.title, task.duration))
+                new_tasks.append(Task(task.task_id, task.title, task.duration,
+                                      task.priority, task.max_resources))
         self.project.tasks = new_tasks
 
     def find_best_resource(self):
@@ -85,14 +89,13 @@ class WorkPlan:
         :rtype: Resource
         :return: resource found
         """
-        lowest_assigned = 999999999
+        lowest_duration = 999999999
         best_res = None
         for res in self.project.resources:
-            assigned_days = len(res.assigned)
-            if assigned_days == 0:
+            if res.duration == 0:
                 return res
-            if assigned_days < lowest_assigned:
-                lowest_assigned = assigned_days
+            if res.duration < lowest_duration:
+                lowest_duration = res.duration
                 best_res = res
         return best_res or self.project.resources[0]
 
@@ -104,9 +107,15 @@ class WorkPlan:
         :param Resource resource: resource
         :param int days: number of days in task to assign
         """
-        resource.assigned.extend([task.task_id] * days)
-        resource.assigned_tasks.append(task.task_id)
-        resource.duration = len(resource.assigned)
+        resource.assigned.append({
+            'task': task.task_id,
+            'duration': days,
+        })
+        resource.assigned_tasks.append({
+            'id': task.task_id,
+            'title': task.title,
+        })
+        resource.duration += days
         if resource.duration > self.duration:
             self.duration = resource.duration
         task.remaining -= days
@@ -114,34 +123,39 @@ class WorkPlan:
 
     def schedule(self):
         """Automatic resource leveling in the project."""
-        for task in self.project.tasks_by_duration():
+        sorted_tasks = self.project.sorted_tasks(['priority', 'duration'],
+                                                 reverse=True)
+        for task in sorted_tasks:
             self.assign_task(task, self.find_best_resource(), task.remaining)
-        sum_usage = 0
+        sum_use = 0
         for res in self.project.resources:
             if res.duration > 0:
                 res.end_date = add_business_days(
                     self.project.start_date,
-                    res.duration,
-                    self.project.dict_holidays,
+                    res.duration - 1,
+                    self.project.hdays,
                 )
                 if res.end_date > self.end_date:
                     self.end_date = res.end_date
-            res.usage = (res.duration * 100) / self.duration
-            sum_usage += res.usage
+            res.use = (res.duration * 100) / self.duration
+            sum_use += res.use
         if self.project.resources:
-            self.resources_usage = sum_usage / len(self.project.resources)
+            self.resources_use = sum_use / len(self.project.resources)
 
     def as_dict(self):
         """Return the work plan as dict."""
+        after_end = self.end_date + datetime.timedelta(days=1)
+        holidays = self.project.hdays[self.project.start_date:after_end]
         return {
             'workplan': {
                 'project': {
                     'name': self.project.name,
-                    'start': self.project.start_date.strftime('%Y-%m-%d'),
-                    'end': self.end_date.strftime('%Y-%m-%d'),
+                    'start': self.project.start_date,
+                    'end': self.end_date,
                     'duration': self.duration,
-                    'holidays': self.project.holidays_iso,
-                    'resources_usage': self.resources_usage,
+                    'holidays_iso': self.project.holidays_iso,
+                    'holidays': holidays,
+                    'resources_use': self.resources_use,
                 },
                 'resources': [
                     {
@@ -150,9 +164,8 @@ class WorkPlan:
                         'assigned': res.assigned,
                         'assigned_tasks': res.assigned_tasks,
                         'duration': res.duration,
-                        'end': (res.end_date.strftime('%Y-%m-%d')
-                                if res.end_date else ''),
-                        'usage': res.usage,
+                        'end': res.end_date or None,
+                        'use': res.use,
                     }
                     for res in self.project.resources
                 ],
@@ -161,6 +174,8 @@ class WorkPlan:
                         'id': task.task_id,
                         'title': task.title,
                         'duration': task.duration,
+                        'priority': task.priority,
+                        'max_resources': task.max_resources,
                     }
                     for task in self.project.tasks
                 ],
@@ -179,7 +194,7 @@ def build_workplan(project):
     """
     tasks_ids = [
         task.task_id
-        for task in project.tasks_by_duration()
+        for task in project.sorted_tasks(['duration'], reverse=True)
         if task.duration > 1
     ]
     best_workplan = WorkPlan(project)
