@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (C) 2020 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2020-2021 Sébastien Helleu <flashcode@flashtux.org>
 #
 # This file is part of Tasksched.
 #
@@ -20,30 +20,30 @@
 
 """Tests on export of work plan to text."""
 
-from .utils import get_json_file
+from tasksched import workplan_to_text
+from .utils import get_input_file
 
 
 def test_workplan_to_text():
     """Test workplan_to_text function."""
-    from tasksched import workplan_to_text
-    workplan = get_json_file('workplan_complete.json')
+    workplan = get_input_file('workplan_complete.yaml')
     text = workplan_to_text(workplan)
     assert '\x1b[0m' in text
     text = workplan_to_text(workplan, use_colors=False)
-    assert ('Developer 1 > 2021-01-04   8d  89% ████▊███   '
+    assert ('Developer 1 > 2020-12-31   8d  89% ████▊██▊   '
             'task3, task2') in text
-    assert ('Developer 2 > 2021-01-05   9d 100% ████▊█▊██  '
+    assert ('Developer 2 > 2021-01-04   9d 100% ████▊█▊█▊  '
             'task3, task1, task2') in text
     text = workplan_to_text(workplan, use_colors=False, use_unicode=False)
-    assert ('Developer 1 > 2021-01-04   8d  89% xxxx|xxx   '
+    assert ('Developer 1 > 2020-12-31   8d  89% [xxx][x]   '
             'task3, task2') in text
-    assert ('Developer 2 > 2021-01-05   9d 100% xxxx|x|xx  '
+    assert ('Developer 2 > 2021-01-04   9d 100% [xxx][][]  '
             'task3, task1, task2') in text
 
-    workplan = get_json_file('workplan_complete2.json')
+    workplan = get_input_file('workplan_complete2.yaml')
     text = workplan_to_text(workplan)
     assert '\x1b[0m' in text
     text = workplan_to_text(workplan, use_colors=False)
-    assert 'Developer 1 > 2020-12-29   5d 100% █████  task1' in text
-    assert 'Developer 2 > 2020-12-29   5d 100% █████  task1' in text
-    assert 'Developer 3 > 2020-12-23   2d  40% ██     task2' in text
+    assert 'Developer 1 > 2020-12-30   7d 100% ████▊█▊  task2, task1' in text
+    assert 'Developer 2 > 2020-12-28   5d  71% ████▊    task3' in text
+    assert 'Developer 3 > 2020-12-28   5d  71% ████▊    task3' in text
